@@ -8,6 +8,7 @@ from random import randint
 from PIL import Image
 from io import BytesIO
 from re import findall
+from pathlib import Path
 
 class Encryption:
     def __init__(self, auth,):
@@ -613,6 +614,27 @@ class Bot:
 				'height':height
 				}}, "client": Clients.web
 				}))},url='https://messengerg2c64.iranlms.ir/').text)['data_enc']))
+			elif text != None and message_id != None:
+				return loads(self.enc.decrypt(loads(post(json={"api_version":"5","auth":self.auth,"data_enc":self.enc.encrypt(dumps({
+				"method":"sendMessage",
+				"input":{
+				"object_guid":chat_id,
+				"rnd":f"{randint(100000,900000)}",
+				"reply_to_message_id":message_id,
+				"text":text,
+				"file_inline":{
+				"dc_id":str(dc_id),
+				"file_id":str(file_id),
+				"type":"Image",
+				"file_name":file_name,
+				"size":size,
+				"mime":mime,
+				"access_hash_rec":access_hash_rec,
+				'thumb_inline':thumb_inline,
+				'width':width,
+				'height':height
+				}}, "client": Clients.web
+				}))},url='https://messengerg2c64.iranlms.ir/').text)['data_enc']))
 			elif message_id != None:
 				return loads(self.enc.decrypt(loads(post(json={"api_version":"5","auth":self.auth,"data_enc":self.enc.encrypt(dumps({
 				"method":"sendMessage",
@@ -653,27 +675,6 @@ class Bot:
 				'height':height
 				}}, "client": Clients.web
 				}))},url='https://messengerg2c64.iranlms.ir/').text)['data_enc']))
-			elif text != None and message_id != None:
-				return loads(self.enc.decrypt(loads(post(json={"api_version":"5","auth":self.auth,"data_enc":self.enc.encrypt(dumps({
-				"method":"sendMessage",
-				"input":{
-				"object_guid":chat_id,
-				"rnd":f"{randint(100000,900000)}",
-				"reply_to_message_id":message_id,
-				"text":text,
-				"file_inline":{
-				"dc_id":str(dc_id),
-				"file_id":str(file_id),
-				"type":"Image",
-				"file_name":file_name,
-				"size":size,
-				"mime":mime,
-				"access_hash_rec":access_hash_rec,
-				'thumb_inline':thumb_inline,
-				'width':width,
-				'height':height
-				}}, "client": Clients.web
-				}))},url='https://messengerg2c64.iranlms.ir/').text)['data_enc']))
 		except: pass
 
 	def sendFile(self, chat_id, file_id , mime , dc_id, access_hash_rec, file_name, size, text=None, message_id=None):
@@ -992,4 +993,100 @@ class Bot:
 				},
 				"client": Clients.web
 			}))},url='https://messengerg2c64.iranlms.ir/').json().get("data_enc")))
-		except: pass
\ No newline at end of file
+		except: pass
+
+class Uploader:
+	def __init__(self, auth,):
+		self.auth=Bot(auth)
+
+	def sendPhoto(self,object_guid, file, caption=None, message_id=None,):
+		if caption!=None and message_id!=None:
+			byte=open(file, 'rb').read()
+			[width,height]=self.auth.getImageSize(byte)
+			rsf=self.auth.requestSendFile('TyperGames.png', len(byte), 'png') # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, 'TyperGames.png', len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,text=caption, message_id=message_id)
+		elif caption==None and message_id==None:
+			byte=open(file, 'rb').read()
+			[width,height]=self.auth.getImageSize(byte)
+			rsf=self.auth.requestSendFile('TyperGames.png', len(byte), 'png') # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, 'TyperGames.png', len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,)
+		elif message_id!=None:
+			byte=open(file, 'rb').read()
+			[width,height]=self.auth.getImageSize(byte)
+			rsf=self.auth.requestSendFile('TyperGames.png', len(byte), 'png') # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, 'TyperGames.png', len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,message_id=message_id,)
+		elif caption!=None:
+			byte=open(file, 'rb').read()
+			[width,height]=self.auth.getImageSize(byte)
+			rsf=self.auth.requestSendFile('TyperGames.png', len(byte), 'png') # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, 'TyperGames.png', len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,text=caption,)
+
+	def sendPhotoWithLink(self, object_guid, link, caption=None, message_id=None):
+		file_name='TyperGames'+str(randint(10000, 999999999))+'.png'
+		if caption!=None and message_id!=None:
+			byte=get(str(link)).content
+			[width,height]=self.auth.getImageSize(byte)
+			rsf=self.auth.requestSendFile(file_name, len(byte), 'png') # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, file_name, len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,text=caption, message_id=message_id)
+		elif (caption==None and message_id==None):
+			byte=get(str(link)).content
+			[width,height]=self.auth.getImageSize(byte)
+			rsf=self.auth.requestSendFile(file_name, len(byte), 'png') # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, file_name, len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,)
+		elif caption!=None:
+			byte=get(str(link)).content
+			[width,height]=self.auth.getImageSize(byte)
+			rsf=self.auth.requestSendFile(file_name, len(byte), 'png') # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, file_name, len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height,text=caption,)
+		elif message_id!=None:
+			byte=get(str(link)).content
+			[width,height]=self.auth.getImageSize(byte)
+			rsf=self.auth.requestSendFile(file_name, len(byte), 'png') # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendImage(object_guid ,rsf['id'] , 'png', rsf['dc_id'] , access, file_name, len(byte), str(self.auth.getThumbInline(byte))[2:-1] , width, height, message_id=message_id,)
+
+	def sendDocument(self, object_guid, file, file_name=None,caption=None, message_id=None):
+		suffix = Path(file).suffix
+		if file_name==None:
+			file_name='TyperGames'+str(randint(10000, 999999999))+suffix
+		else:
+			file_name=file_name+suffix
+		if caption!=None and message_id!=None:
+			byte=open(file, 'rb').read()
+			rsf=self.auth.requestSendFile(file_name, len(byte), suffix[1:]) # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendFile(object_guid,rsf['id'] , suffix[1:], rsf['dc_id'] , access, file_name, len(byte), text=caption,message_id=message_id,)
+		elif caption==None and message_id==None:
+			byte=open(file, 'rb').read()
+			rsf=self.auth.requestSendFile(file_name, len(byte), suffix[1:]) # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendFile(object_guid,rsf['id'] , suffix[1:], rsf['dc_id'] , access, file_name, len(byte),)
+		elif message_id!=None:
+			byte=open(file, 'rb').read()
+			rsf=self.auth.requestSendFile(file_name, len(byte), suffix[1:]) # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendFile(object_guid,rsf['id'] , suffix[1:], rsf['dc_id'] , access, file_name, len(byte), message_id=message_id)
+		elif caption!=None:
+			byte=open(file, 'rb').read()
+			rsf=self.auth.requestSendFile(file_name, len(byte), suffix[1:]) # rsf = request send File
+			if rsf!='many_request':
+				access = self.auth.fileUpload(byte, rsf['access_hash_send'], rsf['id'], rsf['upload_url'])
+				self.auth.sendFile(object_guid,rsf['id'] , suffix[1:], rsf['dc_id'] , access, file_name, len(byte), text=caption)
\ No newline at end of file
